@@ -4,10 +4,10 @@ Name: filter_deinterlace.py
 Porpose: Show dialog to get deinterlace/interlace data based on FFmpeg syntax
 Compatibility: Python3, wxPython Phoenix
 Author: Gianluca Pernigotto <jeanlucperni@gmail.com>
-Copyright: (c) 2018/2021 Gianluca Pernigotto <jeanlucperni@gmail.com>
+Copyleft - 2024 Gianluca Pernigotto <jeanlucperni@gmail.com>
 license: GPL3
-Rev: May.09.2021 *-pycodestyle- compatible*
-########################################################
+Rev: May.09.2024
+Code checker: flake8, pylint
 
 This file is part of Videomass.
 
@@ -30,13 +30,15 @@ import wx
 
 class Deinterlace(wx.Dialog):
     """
-    Show a dialog for image deinterlace/interlace functions
-    with advanced option for each filter.
+    A dialog tool to get video interlacing/deinterlacing values
+    based on FFmpeg syntax.
+    See ``av_conversions.py`` -> ``on_Set_deinterlace`` method
+    for how to use this class.
     """
     get = wx.GetApp()
     appdata = get.appset
 
-    def __init__(self, parent, deinterlace, interlace):
+    def __init__(self, parent, deinterlace, interlace, iconreset):
         """
         Make sure you use the clear button when you finish the task.
         """
@@ -52,10 +54,10 @@ class Deinterlace(wx.Dialog):
 
         self.enable_opt = wx.ToggleButton(self, wx.ID_ANY,
                                           _("Advanced Options"))
-        zone1 = wx.StaticBoxSizer(wx.StaticBox(self, wx.ID_ANY, (
-                                    _("Deinterlace"))), wx.VERTICAL)
-        zone2 = wx.StaticBoxSizer(wx.StaticBox(self, wx.ID_ANY, (
-                                    _("Interlace"))), wx.VERTICAL)
+        boxs = wx.StaticBox(self, wx.ID_ANY, (_("Deinterlace")))
+        zone1 = wx.StaticBoxSizer(boxs, wx.VERTICAL)
+        boxs = wx.StaticBox(self, wx.ID_ANY, (_("Interlace")))
+        zone2 = wx.StaticBoxSizer(boxs, wx.VERTICAL)
 
         self.ckbx_deintW3fdif = wx.CheckBox(self, wx.ID_ANY,
                                             (_("Deinterlaces with "
@@ -112,12 +114,6 @@ class Deinterlace(wx.Dialog):
                                               majorDimension=0,
                                               style=wx.RA_SPECIFY_ROWS
                                               )
-        # ----- confirm buttons section
-        btn_help = wx.Button(self, wx.ID_HELP, "")
-        btn_close = wx.Button(self, wx.ID_CANCEL, "")
-        self.btn_ok = wx.Button(self, wx.ID_OK, _("Apply"))
-        btn_reset = wx.Button(self, wx.ID_CLEAR, _("Reset"))
-
         # set Properties
         self.SetTitle(_("Deinterlacing and Interlacing"))
         self.rdbx_w3fdif.Hide()
@@ -137,58 +133,13 @@ class Deinterlace(wx.Dialog):
         self.rdbx_Yadif_deint.SetSelection(0)
         self.rdbx_inter_scan.SetSelection(0)
         self.rdbx_inter_lowpass.SetSelection(1)
-        self.rdbx_w3fdif.Disable(), self.rdbx_w3fdif_d.Disable(),
-        self.rdbx_Yadif_mode.Disable(),
-        self.rdbx_Yadif_parity.Disable(), self.rdbx_Yadif_deint.Disable(),
-        self.rdbx_inter_scan.Disable(), self.rdbx_inter_lowpass.Disable()
-
-        # ------ set Layout
-        self.sizer_base = wx.BoxSizer(wx.VERTICAL)
-        self.sizer_base.Add(self.enable_opt, 0, wx.ALL | wx.ALIGN_RIGHT, 5)
-        self.sizer_base.Add(zone1, 0, wx.ALL | wx.EXPAND, 5)
-        grid_w3fdif = wx.FlexGridSizer(1, 4, 0, 0)
-        zone1.Add(grid_w3fdif)
-        grid_w3fdif.Add(self.ckbx_deintW3fdif, 0, wx.ALL |
-                        wx.ALIGN_CENTER_VERTICAL |
-                        wx.ALIGN_CENTER_HORIZONTAL, 5)
-        grid_w3fdif.Add(self.rdbx_w3fdif, 0, wx.ALL, 5)
-        grid_w3fdif.Add(self.rdbx_w3fdif_d, 0, wx.ALL, 5)
-        grid_yadif = wx.FlexGridSizer(1, 4, 0, 0)
-        zone1.Add(grid_yadif)
-        grid_yadif.Add(self.ckbx_deintYadif, 0, wx.ALL |
-                       wx.ALIGN_CENTER_VERTICAL |
-                       wx.ALIGN_CENTER_HORIZONTAL, 5)
-        grid_yadif.Add(self.rdbx_Yadif_mode, 0, wx.ALL, 5)
-        grid_yadif.Add(self.rdbx_Yadif_parity, 0, wx.ALL, 5)
-        grid_yadif.Add(self.rdbx_Yadif_deint, 0, wx.ALL, 5)
-        self.sizer_base.Add(zone2, 0, wx.ALL | wx.EXPAND, 5)
-        inter_grid = wx.FlexGridSizer(1, 3, 0, 0)
-        zone2.Add(inter_grid)
-        inter_grid.Add(self.ckbx_interlace, 0, wx.ALL |
-                       wx.ALIGN_CENTER_VERTICAL |
-                       wx.ALIGN_CENTER_HORIZONTAL, 5)
-        inter_grid.Add(self.rdbx_inter_scan, 0, wx.ALL, 5)
-        inter_grid.Add(self.rdbx_inter_lowpass, 0, wx.ALL, 5)
-
-        # confirm btn section:
-        self.gridBtn = wx.GridSizer(1, 2, 0, 0)
-        gridhelp = wx.GridSizer(1, 1, 0, 0)
-
-        gridhelp.Add(btn_help, 0, wx.ALL | wx.ALIGN_CENTER_VERTICAL, 5)
-        self.gridBtn.Add(gridhelp)
-        self.gridexit = wx.BoxSizer(wx.HORIZONTAL)
-
-        self.gridexit.Add(btn_close, 0, wx.ALL | wx.ALIGN_CENTER_VERTICAL, 5)
-        self.gridexit.Add(self.btn_ok, 0, wx.ALL | wx.ALIGN_CENTER_VERTICAL, 5)
-        self.gridexit.Add(btn_reset, 0, wx.ALL | wx.ALIGN_CENTER_VERTICAL, 5)
-        self.gridBtn.Add(self.gridexit, 0, wx.ALL |
-                         wx.ALIGN_RIGHT | wx.RIGHT, 0
-                         )
-        self.sizer_base.Add(self.gridBtn, 0, wx.EXPAND)
-        # final settings:
-        self.SetSizer(self.sizer_base)
-        self.sizer_base.Fit(self)
-        self.Layout()
+        self.rdbx_w3fdif.Disable()
+        self.rdbx_w3fdif_d.Disable()
+        self.rdbx_Yadif_mode.Disable()
+        self.rdbx_Yadif_parity.Disable()
+        self.rdbx_Yadif_deint.Disable()
+        self.rdbx_inter_scan.Disable()
+        self.rdbx_inter_lowpass.Disable()
 
         self.ckbx_deintW3fdif.SetToolTip(_('Deinterlace the input video '
                                            'with `w3fdif` filter'))
@@ -217,6 +168,54 @@ class Deinterlace(wx.Dialog):
                   'moire patterns.\nDefault is no setting.')
         self.rdbx_inter_lowpass.SetToolTip(toolt)
 
+        self.sizer_base = wx.BoxSizer(wx.VERTICAL)
+        self.sizer_base.Add(self.enable_opt, 0, wx.ALL | wx.ALIGN_RIGHT, 5)
+        self.sizer_base.Add(zone1, 0, wx.ALL | wx.EXPAND, 5)
+        grid_w3fdif = wx.FlexGridSizer(1, 4, 0, 0)
+        zone1.Add(grid_w3fdif)
+        grid_w3fdif.Add(self.ckbx_deintW3fdif, 0, wx.ALL
+                        | wx.ALIGN_CENTER_VERTICAL
+                        | wx.ALIGN_CENTER_HORIZONTAL, 5)
+        grid_w3fdif.Add(self.rdbx_w3fdif, 0, wx.ALL, 5)
+        grid_w3fdif.Add(self.rdbx_w3fdif_d, 0, wx.ALL, 5)
+        grid_yadif = wx.FlexGridSizer(1, 4, 0, 0)
+        zone1.Add(grid_yadif)
+        grid_yadif.Add(self.ckbx_deintYadif, 0, wx.ALL
+                       | wx.ALIGN_CENTER_VERTICAL
+                       | wx.ALIGN_CENTER_HORIZONTAL, 5)
+        grid_yadif.Add(self.rdbx_Yadif_mode, 0, wx.ALL, 5)
+        grid_yadif.Add(self.rdbx_Yadif_parity, 0, wx.ALL, 5)
+        grid_yadif.Add(self.rdbx_Yadif_deint, 0, wx.ALL, 5)
+        self.sizer_base.Add(zone2, 0, wx.ALL | wx.EXPAND, 5)
+        inter_grid = wx.FlexGridSizer(1, 3, 0, 0)
+        zone2.Add(inter_grid)
+        inter_grid.Add(self.ckbx_interlace, 0, wx.ALL
+                       | wx.ALIGN_CENTER_VERTICAL
+                       | wx.ALIGN_CENTER_HORIZONTAL, 5)
+        inter_grid.Add(self.rdbx_inter_scan, 0, wx.ALL, 5)
+        inter_grid.Add(self.rdbx_inter_lowpass, 0, wx.ALL, 5)
+
+        # ----- confirm buttons section
+        gridbtns = wx.GridSizer(1, 2, 0, 0)
+        gridhelp = wx.GridSizer(1, 1, 0, 0)
+        btn_help = wx.Button(self, wx.ID_HELP, "")
+        gridhelp.Add(btn_help, 0, wx.ALL | wx.ALIGN_CENTER_VERTICAL, 5)
+        gridbtns.Add(gridhelp)
+        boxaff = wx.BoxSizer(wx.HORIZONTAL)
+        btn_cancel = wx.Button(self, wx.ID_CANCEL, "")
+        boxaff.Add(btn_cancel, 0)
+        btn_ok = wx.Button(self, wx.ID_OK)
+        boxaff.Add(btn_ok, 0, wx.LEFT, 5)
+        btn_reset = wx.Button(self, wx.ID_ANY, _("Reset"))
+        btn_reset.SetBitmap(iconreset, wx.LEFT)
+        boxaff.Add(btn_reset, 0, wx.LEFT, 5)
+        gridbtns.Add(boxaff, 0, wx.ALL | wx.ALIGN_RIGHT | wx.RIGHT, border=5)
+        self.sizer_base.Add(gridbtns, 0, wx.EXPAND)
+        # ----- Set layout
+        self.SetSizer(self.sizer_base)
+        self.sizer_base.Fit(self)
+        self.Layout()
+
         # ----------------------Binding (EVT)-------------------------#
         self.Bind(wx.EVT_CHECKBOX, self.on_DeintW3fdif, self.ckbx_deintW3fdif)
         self.Bind(wx.EVT_RADIOBOX, self.on_W3fdif_filter, self.rdbx_w3fdif)
@@ -229,8 +228,8 @@ class Deinterlace(wx.Dialog):
         self.Bind(wx.EVT_RADIOBOX, self.on_intScan, self.rdbx_inter_scan)
         self.Bind(wx.EVT_RADIOBOX, self.on_intLowpass, self.rdbx_inter_lowpass)
         self.Bind(wx.EVT_TOGGLEBUTTON, self.Advanced_Opt, self.enable_opt)
-        self.Bind(wx.EVT_BUTTON, self.on_close, btn_close)
-        self.Bind(wx.EVT_BUTTON, self.on_ok, self.btn_ok)
+        self.Bind(wx.EVT_BUTTON, self.on_close, btn_cancel)
+        self.Bind(wx.EVT_BUTTON, self.on_ok, btn_ok)
         self.Bind(wx.EVT_BUTTON, self.on_reset, btn_reset)
         self.Bind(wx.EVT_BUTTON, self.on_help, btn_help)
 
@@ -260,23 +259,24 @@ class Deinterlace(wx.Dialog):
                 self.ckbx_interlace.Disable()
                 self.rdbx_w3fdif.Enable()
                 self.rdbx_w3fdif_d.Enable()
-                indx = self.cmd_opt["deinterlace"].split('=')[1].split(':')
-                if indx[0] == 'complex':
+                indx = self.cmd_opt["deinterlace"].split(':')
+                if indx[0].split('=')[2] == 'complex':
                     filt = 1
-                elif indx[0] == 'simple':
+                elif indx[0].split('=')[2] == 'simple':
                     filt = 0
                 self.rdbx_w3fdif.SetSelection(filt)
-                if indx[1] == 'all':
+                if indx[1].split('=')[1] == 'all':
                     deint = 0
-                elif indx[1] == 'interlaced':
+                elif indx[1].split('=')[1] == 'interlaced':
                     deint = 1
                 self.rdbx_w3fdif_d.SetSelection(deint)
 
         elif 'interlace' in self.cmd_opt:
             self.ckbx_interlace.SetValue(True)
-            self.ckbx_deintW3fdif.Disable(), self.ckbx_deintYadif.Disable(),
-            self.rdbx_inter_scan.Enable(), self.rdbx_inter_lowpass.Enable(),
-
+            self.ckbx_deintW3fdif.Disable()
+            self.ckbx_deintYadif.Disable()
+            self.rdbx_inter_scan.Enable()
+            self.rdbx_inter_lowpass.Enable()
             scan = self.cmd_opt["interlace"].split('=')[2].split(':')
             if 'tff' in scan[0]:
                 scan = 0
@@ -296,115 +296,138 @@ class Deinterlace(wx.Dialog):
 
     def on_DeintW3fdif(self, event):
         """
+        Enable/disable Deinterlace using `W3fdif` filter
         """
         if self.ckbx_deintW3fdif.IsChecked():
-            self.rdbx_w3fdif.Enable(), self.rdbx_w3fdif_d.Enable(),
-            self.ckbx_deintYadif.Disable(), self.ckbx_interlace.Disable()
-            self.cmd_opt["deinterlace"] = "w3fdif=complex:all"
+            self.rdbx_w3fdif.Enable()
+            self.rdbx_w3fdif_d.Enable()
+            self.ckbx_deintYadif.Disable()
+            self.ckbx_interlace.Disable()
+            self.cmd_opt["deinterlace"] = "w3fdif=filter=complex:deint=all"
 
         elif not self.ckbx_deintW3fdif.IsChecked():
-            self.rdbx_w3fdif.Disable(), self.rdbx_w3fdif_d.Disable(),
-            self.ckbx_deintYadif.Enable(), self.ckbx_interlace.Enable(),
+            self.rdbx_w3fdif.Disable()
+            self.rdbx_w3fdif_d.Disable()
+            self.ckbx_deintYadif.Enable()
+            self.ckbx_interlace.Enable()
             self.cmd_opt.clear()
     # ------------------------------------------------------------------#
 
     def on_W3fdif_filter(self, event):
         """
+        When `W3fdif` is enabled, even enables the `Filter`
+        radiobox control for setting the additional parameter
+        to `simple` or `complex`, default is `complex`.
         """
-        self.cmd_opt["deinterlace"] = "w3fdif=%s:%s" % (
-                                self.rdbx_w3fdif.GetStringSelection(),
-                                self.rdbx_w3fdif_d.GetStringSelection()
-                                                    )
+        val = (f"w3fdif=filter={self.rdbx_w3fdif.GetStringSelection()}:"
+               f"deint={self.rdbx_w3fdif_d.GetStringSelection()}")
+        self.cmd_opt["deinterlace"] = val
     # ------------------------------------------------------------------#
 
     def on_W3fdif_deint(self, event):
         """
+        When `W3fdif` is enabled, even enables the `Deint`
+        radiobox control for setting the additional parameters
+        to `all` or `interlaced`, default is `all`.
         """
-        self.cmd_opt["deinterlace"] = "w3fdif=%s:%s" % (
-                                self.rdbx_w3fdif.GetStringSelection(),
-                                self.rdbx_w3fdif_d.GetStringSelection()
-                                                    )
+        val = (f"w3fdif=filter={self.rdbx_w3fdif.GetStringSelection()}:"
+               f"deint={self.rdbx_w3fdif_d.GetStringSelection()}")
+        self.cmd_opt["deinterlace"] = val
     # ------------------------------------------------------------------#
 
     def on_DeintYadif(self, event):
         """
+        Enable/disable Deinterlace using `yadif` filter
         """
         if self.ckbx_deintYadif.IsChecked():
-            self.ckbx_deintW3fdif.Disable(), self.rdbx_Yadif_mode.Enable(),
-            self.rdbx_Yadif_parity.Enable(), self.rdbx_Yadif_deint.Enable(),
-            self.ckbx_interlace.Disable(),
+            self.ckbx_deintW3fdif.Disable()
+            self.rdbx_Yadif_mode.Enable()
+            self.rdbx_Yadif_parity.Enable()
+            self.rdbx_Yadif_deint.Enable()
+            self.ckbx_interlace.Disable()
             self.cmd_opt["deinterlace"] = "yadif=0:-1:0"
 
         elif not self.ckbx_deintYadif.IsChecked():
-            self.ckbx_deintW3fdif.Enable(), self.rdbx_Yadif_mode.Disable(),
-            self.rdbx_Yadif_parity.Disable(), self.rdbx_Yadif_deint.Disable(),
-            self.ckbx_interlace.Enable(),
+            self.ckbx_deintW3fdif.Enable()
+            self.rdbx_Yadif_mode.Disable()
+            self.rdbx_Yadif_parity.Disable()
+            self.rdbx_Yadif_deint.Disable()
+            self.ckbx_interlace.Enable()
             self.cmd_opt.clear()
     # ------------------------------------------------------------------#
 
     def on_modeYadif(self, event):
         """
+        When `yadif` is enabled, even enables the `Mode`
+        radiobox control for setting additional parameters.
         """
         parity = self.rdbx_Yadif_parity.GetStringSelection().split(',')
-        self.cmd_opt["deinterlace"] = "yadif=%s:%s:%s" % (
-                                self.rdbx_Yadif_mode.GetStringSelection()[0],
-                                parity[0],
-                                self.rdbx_Yadif_deint.GetStringSelection()[0]
-                                                    )
+        val = (f"yadif={self.rdbx_Yadif_mode.GetStringSelection()[0]}:"
+               f"{parity[0]}:{self.rdbx_Yadif_deint.GetStringSelection()[0]}")
+        self.cmd_opt["deinterlace"] = val
     # ------------------------------------------------------------------#
 
     def on_parityYadif(self, event):
         """
+        When `yadif` is enabled, even enables the `Parity`
+        radiobox control for setting additional parameters.
         """
         parity = self.rdbx_Yadif_parity.GetStringSelection().split(',')
-        self.cmd_opt["deinterlace"] = "yadif=%s:%s:%s" % (
-                                self.rdbx_Yadif_mode.GetStringSelection()[0],
-                                parity[0],
-                                self.rdbx_Yadif_deint.GetStringSelection()[0]
-                                                    )
+
+        val = (f"yadif={self.rdbx_Yadif_mode.GetStringSelection()[0]}:"
+               f"{parity[0]}:{self.rdbx_Yadif_deint.GetStringSelection()[0]}")
+        self.cmd_opt["deinterlace"] = val
     # ------------------------------------------------------------------#
 
     def on_deintYadif(self, event):
         """
+        When `yadif` is enabled, even enables the `Deint`
+        radiobox control for setting additional parameters.
         """
         parity = self.rdbx_Yadif_parity.GetStringSelection().split(',')
-        self.cmd_opt["deinterlace"] = "yadif=%s:%s:%s" % (
-                                self.rdbx_Yadif_mode.GetStringSelection()[0],
-                                parity[0],
-                                self.rdbx_Yadif_deint.GetStringSelection()[0]
-                                                    )
+        val = (f"yadif={self.rdbx_Yadif_mode.GetStringSelection()[0]}:"
+               f"{parity[0]}:{self.rdbx_Yadif_deint.GetStringSelection()[0]}")
+        self.cmd_opt["deinterlace"] = val
     # ------------------------------------------------------------------#
 
     def on_Interlace(self, event):
         """
+        Enable/disable Deinterlace using `yadif` filter
         """
         if self.ckbx_interlace.IsChecked():
-            self.ckbx_deintW3fdif.Disable(), self.ckbx_deintYadif.Disable(),
-            self.rdbx_inter_scan.Enable(), self.rdbx_inter_lowpass.Enable(),
+            self.ckbx_deintW3fdif.Disable()
+            self.ckbx_deintYadif.Disable()
+            self.rdbx_inter_scan.Enable()
+            self.rdbx_inter_lowpass.Enable()
             self.cmd_opt["interlace"] = "interlace=scan=tff:lowpass=1"
 
         elif not self.ckbx_interlace.IsChecked():
-            self.ckbx_deintW3fdif.Enable(), self.ckbx_deintYadif.Enable(),
-            self.rdbx_inter_scan.Disable(), self.rdbx_inter_lowpass.Disable(),
+            self.ckbx_deintW3fdif.Enable()
+            self.ckbx_deintYadif.Enable()
+            self.rdbx_inter_scan.Disable()
+            self.rdbx_inter_lowpass.Disable()
             self.cmd_opt.clear()
     # ------------------------------------------------------------------#
 
     def on_intScan(self, event):
         """
+        When `interlace` is enabled, even enables the `Scanning mode`
+        radiobox control for setting additional parameters.
         """
-        self.cmd_opt["interlace"] = "interlace=%s:%s" % (
-                                self.rdbx_inter_scan.GetStringSelection(),
-                                self.rdbx_inter_lowpass.GetStringSelection(),
-                                                     )
+        val = (f"interlace={self.rdbx_inter_scan.GetStringSelection()}:"
+               f"{self.rdbx_inter_lowpass.GetStringSelection()}")
+        self.cmd_opt["interlace"] = val
     # ------------------------------------------------------------------#
 
     def on_intLowpass(self, event):
         """
+        When `interlace` is enabled, even enables the
+        `Set vertical low-pass filter` radiobox control
+        for setting additional parameters.
         """
-        self.cmd_opt["interlace"] = "interlace=%s:%s" % (
-                                self.rdbx_inter_scan.GetStringSelection(),
-                                self.rdbx_inter_lowpass.GetStringSelection(),
-                                                     )
+        val = (f"interlace={self.rdbx_inter_scan.GetStringSelection()}:"
+               f"{self.rdbx_inter_lowpass.GetStringSelection()}")
+        self.cmd_opt["interlace"] = val
     # ------------------------------------------------------------------#
 
     def Advanced_Opt(self, event):
@@ -454,9 +477,12 @@ class Deinterlace(wx.Dialog):
         self.rdbx_Yadif_deint.SetSelection(0)
         self.rdbx_inter_scan.SetSelection(0)
         self.rdbx_inter_lowpass.SetSelection(1)
-        self.rdbx_w3fdif.Disable(), self.rdbx_w3fdif_d.Disable(),
-        self.rdbx_Yadif_mode.Disable(), self.rdbx_Yadif_parity.Disable(),
-        self.rdbx_Yadif_deint.Disable(), self.rdbx_inter_scan.Disable(),
+        self.rdbx_w3fdif.Disable()
+        self.rdbx_w3fdif_d.Disable()
+        self.rdbx_Yadif_mode.Disable()
+        self.rdbx_Yadif_parity.Disable()
+        self.rdbx_Yadif_deint.Disable()
+        self.rdbx_inter_scan.Disable()
         self.rdbx_inter_lowpass.Disable()
     # ------------------------------------------------------------------#
 
@@ -465,38 +491,29 @@ class Deinterlace(wx.Dialog):
         Open default web browser via Python Web-browser controller.
         see <https://docs.python.org/3.8/library/webbrowser.html>
         """
-        if Deinterlace.appdata['GETLANG'] in Deinterlace.appdata['SUPP_LANGs']:
-            lang = Deinterlace.appdata['GETLANG'].split('_')[0]
-            page = ('https://jeanslack.github.io/Videomass/Pages/User-guide-'
-                    'languages/%s/4-Video_filters_%s.pdf' % (lang, lang))
-        else:
-            page = ('https://jeanslack.github.io/Videomass/Pages/User-guide-'
-                    'languages/en/4-Video_filters_en.pdf')
+        page = ('https://jeanslack.github.io/Videomass/User-guide'
+                '/Video_filters_en.pdf')
 
         webbrowser.open(page)
     # ------------------------------------------------------------------#
 
     def on_close(self, event):
-
+        """
+        Close this dialog without saving anything
+        """
         event.Skip()
     # ------------------------------------------------------------------#
 
     def on_ok(self, event):
         """
-        if you enable self.Destroy(), it delete from memory all data
-        event and no return correctly. It has the right behavior if
-        not used here, because it is called in the main frame.
-
-        Event.Skip(), work correctly here. Sometimes needs to disable
-        it for needs to maintain the view of the window (for exemple).
+        Don't use self.Destroy() in this dialog
         """
-        self.getvalue()
-        # self.Destroy()
         event.Skip()
     # ------------------------------------------------------------------#
 
     def getvalue(self):
         """
-        This method return values via the interface GetValue()
+        This method return values via the getvalue() interface
+        from the caller. See the caller for more info and usage.
         """
         return self.cmd_opt
