@@ -4,11 +4,10 @@ Name: wizard_dlg.py
 Porpose: wizard setup dialog
 Compatibility: Python3, wxPython Phoenix
 Author: Gianluca Pernigotto <jeanlucperni@gmail.com>
-Copyright: (c) 2018/2022 Gianluca Pernigotto <jeanlucperni@gmail.com>
+Copyleft - 2024 Gianluca Pernigotto <jeanlucperni@gmail.com>
 license: GPL3
-Rev: Feb.11.2022
+Rev: April.14.2024
 Code checker: flake8, pylint
-########################################################
 
 This file is part of Videomass.
 
@@ -31,13 +30,18 @@ from videomass.vdms_utils.utils import detect_binaries
 from videomass.vdms_sys.settings_manager import ConfigManager
 
 
-def write_changes(fileconf, ffmpeg, ffplay, ffprobe, youtubedl, binfound):
+def write_changes(ffmpeg, ffplay, ffprobe, youtubedl, binfound):
     """
     Writes changes to the configuration file
 
     """
-    conf = ConfigManager(fileconf)
+    get = wx.GetApp()
+    appdata = get.appset
+    conf = ConfigManager(appdata['fileconfpath'])
     dataread = conf.read_options()
+    if not dataread['trashdir_loc'].strip():
+        # prevent Nonetype error saving settings from preferences
+        dataread['trashdir_loc'] = appdata['trashdir_default']
     dataread['ffmpeg_cmd'] = ffmpeg
     dataread['ffprobe_cmd'] = ffprobe
     dataread['ffplay_cmd'] = ffplay
@@ -46,7 +50,8 @@ def write_changes(fileconf, ffmpeg, ffplay, ffprobe, youtubedl, binfound):
     dataread['ffmpeg_islocal'] = local
     dataread['ffprobe_islocal'] = local
     dataread['ffplay_islocal'] = local
-    dataread['downloader'] = youtubedl
+    dataread['use-downloader'] = youtubedl
+
     conf.write_options(**dataread)
 
 
@@ -57,8 +62,8 @@ class PageOne(wx.Panel):
     """
     get = wx.GetApp()
     OS = get.appset['ostype']
-    MSG2 = (_("Please take a moment to set up the application"))
-    MSG3 = (_('Click the "Next" button to get started'))
+    MSG2 = _("Please take a moment to set up the application")
+    MSG3 = _('Click the "Next" button to get started')
 
     def __init__(self, parent, icon):
         """
@@ -75,8 +80,8 @@ class PageOne(wx.Panel):
         lab1 = wx.StaticText(self, wx.ID_ANY,
                              _("Welcome to the Videomass Wizard!"))
         lab2 = wx.StaticText(self, wx.ID_ANY, PageOne.MSG2,
-                             style=wx.ST_ELLIPSIZE_END |
-                             wx.ALIGN_CENTRE_HORIZONTAL
+                             style=wx.ST_ELLIPSIZE_END
+                             | wx.ALIGN_CENTRE_HORIZONTAL,
                              )
         lab3 = wx.StaticText(self, wx.ID_ANY, PageOne.MSG3,
                              style=wx.ALIGN_CENTRE_HORIZONTAL)
@@ -115,7 +120,7 @@ class PageTwo(wx.Panel):
     GETPATH = get.appset['getpath']
     FFMPEG_LOCALDIR = get.appset['FFMPEG_videomass_pkg']
 
-    MSG0 = (_('Videomass is an application based on FFmpeg\n'))
+    MSG0 = _('Videomass is an application based on FFmpeg\n')
 
     MSG1 = (_('If FFmpeg is not on your computer, this application '
               'will be unusable'))
@@ -138,8 +143,8 @@ class PageTwo(wx.Panel):
         sizer_base = wx.BoxSizer(wx.VERTICAL)
         sizerText = wx.BoxSizer(wx.VERTICAL)
         lab0 = wx.StaticText(self, wx.ID_ANY, PageTwo.MSG0,
-                             style=wx.ST_ELLIPSIZE_END |
-                             wx.ALIGN_CENTRE_HORIZONTAL
+                             style=wx.ST_ELLIPSIZE_END
+                             | wx.ALIGN_CENTRE_HORIZONTAL,
                              )
         lab1 = wx.StaticText(self, wx.ID_ANY, PageTwo.MSG1,
                              style=wx.ALIGN_CENTRE_HORIZONTAL)
@@ -150,8 +155,8 @@ class PageTwo(wx.Panel):
         self.locateBtn = wx.Button(self, wx.ID_ANY, _("Locate"),
                                    size=(250, -1))
         self.labFFpath = wx.StaticText(self, wx.ID_ANY, "",
-                                       style=wx.ST_ELLIPSIZE_END |
-                                       wx.ALIGN_CENTRE_HORIZONTAL
+                                       style=wx.ST_ELLIPSIZE_END
+                                       | wx.ALIGN_CENTRE_HORIZONTAL,
                                        )
         if PageTwo.OS == 'Darwin':
             lab0.SetFont(wx.Font(14, wx.DEFAULT, wx.ITALIC, wx.NORMAL, 0, ""))
@@ -215,13 +220,13 @@ class PageTwo(wx.Panel):
 
         exiting = None
         path = []
-        for x in executable:
-            status = detect_binaries(PageTwo.OS, x, PageTwo.FFMPEG_LOCALDIR)
+        for exe in executable:
+            status = detect_binaries(exe, PageTwo.FFMPEG_LOCALDIR)
 
             if status[0] == 'not installed':
                 wx.MessageBox(_("'{}' is not installed on your computer. "
-                                "Install it or indicate another location "
-                                "by clicking the 'Locate' button.").format(x),
+                                "Install it or indicate another location by "
+                                "clicking the 'Locate' button.").format(exe),
                               'Videomass: Warning', wx.ICON_EXCLAMATION, self)
                 return
 
@@ -235,8 +240,8 @@ class PageTwo(wx.Panel):
         if exiting == 'provided':
             if wx.MessageBox(_("Videomass already seems to include "
                                "FFmpeg.\n\nDo you want to use that?"),
-                             _('Videomass: Please Confirm'),
-                             wx.ICON_QUESTION | wx.YES_NO,  None) == wx.NO:
+                             _('Please confirm'), wx.ICON_QUESTION
+                             | wx.CANCEL | wx.YES_NO, self) != wx.YES:
                 return
 
         self.parent.ffmpeg = PageTwo.GETPATH(path[0])
@@ -259,7 +264,7 @@ class PageThree(wx.Panel):
     OS = get.appset['ostype']
     GETPATH = get.appset['getpath']
 
-    MSG0 = (_('Locating FFmpeg executables\n'))
+    MSG0 = _('Locating FFmpeg executables\n')
 
     MSG1 = (_('"ffmpeg", "ffprobe" and "ffplay" are required. Complete all\n'
               'the text boxes below by clicking on the respective buttons.'))
@@ -284,8 +289,8 @@ class PageThree(wx.Panel):
         sizer_base = wx.BoxSizer(wx.VERTICAL)
         sizerText = wx.BoxSizer(wx.VERTICAL)
         lab0 = wx.StaticText(self, wx.ID_ANY, PageThree.MSG0,
-                             style=wx.ST_ELLIPSIZE_END |
-                             wx.ALIGN_CENTRE_HORIZONTAL
+                             style=wx.ST_ELLIPSIZE_END
+                             | wx.ALIGN_CENTRE_HORIZONTAL,
                              )
         lab1 = wx.StaticText(self, wx.ID_ANY, PageThree.MSG1)
         #  ffmpeg
@@ -343,9 +348,9 @@ class PageThree(wx.Panel):
         """
         Open filedialog to locate ffmpeg executable
         """
-        with wx.FileDialog(self, _("Choose the {} "
-                                   "executable").format(self.ffmpeg), "", "",
-                           f"ffmpeg binary (*{self.ffmpeg})|*{self.ffmpeg}| "
+        with wx.FileDialog(self, _("{} location").format(self.ffmpeg),
+                           "", "", "ffmpeg binary "
+                           f"(*{self.ffmpeg})|*{self.ffmpeg}| "
                            f"All files (*.*)|*.*",
                            wx.FD_OPEN | wx.FD_FILE_MUST_EXIST) as dlgfile:
 
@@ -360,9 +365,8 @@ class PageThree(wx.Panel):
         """
         Open filedialog to locate ffprobe executable
         """
-        with wx.FileDialog(self, _("Choose the {} executable"
-                                   ).format(self.ffprobe), "", "",
-                           f"ffprobe binary "
+        with wx.FileDialog(self, _("{} location").format(self.ffprobe),
+                           "", "", "ffprobe binary "
                            f"(*{self.ffprobe})|*{self.ffprobe}| "
                            f"All files (*.*)|*.*",
                            wx.FD_OPEN | wx.FD_FILE_MUST_EXIST) as dlgfile:
@@ -378,9 +382,9 @@ class PageThree(wx.Panel):
         """
         Open filedialog to locate ffplay executable
         """
-        with wx.FileDialog(self, _("Choose the {} executable"
-                                   ).format(self.ffplay), "", "",
-                           f"ffplay binary (*{self.ffplay})|*{self.ffplay}| "
+        with wx.FileDialog(self, _("{} location").format(self.ffplay),
+                           "", "", "ffplay binary "
+                           f"(*{self.ffplay})|*{self.ffplay}| "
                            f"All files (*.*)|*.*",
                            wx.FD_OPEN | wx.FD_FILE_MUST_EXIST) as dlgfile:
 
@@ -401,9 +405,7 @@ class PageFour(wx.Panel):
     get = wx.GetApp()
     OS = get.appset['ostype']
 
-    MSG0 = _('Videomass has a simple graphical\n'
-             'interface for youtube-dl and yt-dlp\n')
-
+    MSG0 = _('Videomass has a simple graphical interface for yt-dlp\n')
     MSG1 = _('This feature allows you to download video and audio from\n'
              'many sites, including YouTube.com and even Facebook.')
 
@@ -419,28 +421,17 @@ class PageFour(wx.Panel):
         sizerText = wx.BoxSizer(wx.VERTICAL)
 
         lab0 = wx.StaticText(self, wx.ID_ANY, PageFour.MSG0,
-                             style=wx.ST_ELLIPSIZE_END |
-                             wx.ALIGN_CENTRE_HORIZONTAL
+                             style=wx.ST_ELLIPSIZE_END
+                             | wx.ALIGN_CENTRE_HORIZONTAL,
                              )
         lab1 = wx.StaticText(self, wx.ID_ANY, PageFour.MSG1)
         descr = _(" Do you want to enable this feature?")
         self.ckbx_yn = wx.CheckBox(self, wx.ID_ANY, (descr))
-        self.rdbDownloader = wx.RadioBox(self, wx.ID_ANY,
-                                         (_("Downloader preferences")),
-                                         choices=[('youtube_dl'),
-                                                  ('yt_dlp')],
-                                         majorDimension=1,
-                                         style=wx.RA_SPECIFY_COLS
-                                         )
-        self.rdbDownloader.SetSelection(1)
-        self.rdbDownloader.Disable()
 
         if PageFour.OS == 'Darwin':
             lab0.SetFont(wx.Font(14, wx.DEFAULT, wx.ITALIC, wx.NORMAL, 0, ""))
-
         else:
             lab0.SetFont(wx.Font(12, wx.DEFAULT, wx.ITALIC, wx.NORMAL, 0, ""))
-
         # layout
         sizer_base.Add((0, 50), 0)
         sizer_base.Add(lab0, 0, wx.CENTER | wx.EXPAND)
@@ -450,30 +441,12 @@ class PageFour(wx.Panel):
         sizerText.Add(lab1, 0, wx.CENTER | wx.EXPAND)
         sizerText.Add((0, 50), 0)
         sizerText.Add(self.ckbx_yn, 0, wx.CENTER | wx.ALL, 10)
-        sizerText.Add((0, 20), 0)
-        sizerText.Add(self.rdbDownloader, 0, wx.ALL | wx.EXPAND, 10)
         sizerText.Add((0, 50), 0)
 
         self.SetSizer(sizer_base)
         sizer_base.Fit(self)
         self.Layout()
 
-        self.Bind(wx.EVT_CHECKBOX, self.choose_Youtubedl, self.ckbx_yn)
-
-    def choose_Youtubedl(self, event):
-        """
-        the values are get on Wizard.wizard_Finish method
-        """
-        if self.ckbx_yn.IsChecked() is False:
-            self.rdbDownloader.Disable()
-        else:
-            self.rdbDownloader.Enable()
-
-        # if self.ckbx_yn.IsChecked() is False:
-            # self.parent.youtubedl = 'disabled'
-        # else:
-            # self.parent.youtubedl = 'enable'
-
 
 class PageFinish(wx.Panel):
     """
@@ -484,9 +457,9 @@ class PageFinish(wx.Panel):
     OS = get.appset['ostype']
     MSG0 = _("Wizard completed successfully!\n")
     MSG1 = (_("Remember that you can always change these settings "
-              "later, through the Setup dialog."))
+              "later, through the Preferences dialog."))
     MSG3 = _("Thank You!")
-    MSG2 = (_('To exit click the "Finish" button'))
+    MSG2 = _('To exit click the "Finish" button')
 
     def __init__(self, parent):
         """
@@ -537,10 +510,6 @@ class Wizard(wx.Dialog):
     for configuring Videomass during the startup.
 
     """
-    get = wx.GetApp()
-    getfileconf = get.appset['fileconfpath']
-    OS = get.appset['ostype']
-
     def __init__(self, icon_videomass):
         """
         Note that the attributes of ffmpeg are set in the "PageTwo"
@@ -552,8 +521,10 @@ class Wizard(wx.Dialog):
         self.ffprobe = None
         self.ffplay = None
 
-        wx.Dialog.__init__(self, None, -1, style=wx.DEFAULT_DIALOG_STYLE |
-                           wx.RESIZE_BORDER)
+        wx.Dialog.__init__(self, None, -1,
+                           style=wx.DEFAULT_DIALOG_STYLE
+                           | wx.RESIZE_BORDER,
+                           )
         mainSizer = wx.BoxSizer(wx.VERTICAL)  # sizer base global
         self.pageOne = PageOne(self, icon_videomass)  # start...
         self.pageTwo = PageTwo(self)  # choose ffmpeg modality
@@ -621,8 +592,8 @@ class Wizard(wx.Dialog):
             self.pageTwo.Show()
             self.btnBack.Enable()
 
-            if (self.pageTwo.locateBtn.IsEnabled() and
-                    self.pageTwo.detectBtn.IsEnabled()):
+            if (self.pageTwo.locateBtn.IsEnabled()
+                    and self.pageTwo.detectBtn.IsEnabled()):
                 self.btnNext.Disable()
 
         elif self.pageTwo.IsShown():
@@ -635,14 +606,14 @@ class Wizard(wx.Dialog):
                 self.pageFour.Show()
 
         elif self.pageThree.IsShown():
-            if (self.pageThree.ffmpegTxt.GetValue() and
-                    self.pageThree.ffprobeTxt.GetValue() and
-                    self.pageThree.ffplayTxt.GetValue()):
+            if (self.pageThree.ffmpegTxt.GetValue()
+                    and self.pageThree.ffprobeTxt.GetValue()
+                    and self.pageThree.ffplayTxt.GetValue()):
                 self.pageThree.Hide()
                 self.pageFour.Show()
             else:
                 wx.MessageBox(_("Some text boxes are still incomplete"),
-                              ("Videomass"), wx.ICON_INFORMATION, self)
+                              "Videomass", wx.ICON_INFORMATION, self)
 
         elif self.pageFour.IsShown():
             self.pageOne.Hide()
@@ -692,19 +663,13 @@ class Wizard(wx.Dialog):
         to applies changes.
 
         """
-        if self.pageFour.ckbx_yn.IsChecked():
-            index = self.pageFour.rdbDownloader.GetSelection()
-            youtubedl = f'{self.pageFour.rdbDownloader.GetString(index)}'
-        else:
-            youtubedl = 'disabled'
-
+        youtubedl = self.pageFour.ckbx_yn.GetValue()
         if not self.pageTwo.locateBtn.IsEnabled():
             binfound = 'local'
         elif not self.pageTwo.detectBtn.IsEnabled():
             binfound = 'system'
 
-        write_changes(Wizard.getfileconf,
-                      self.ffmpeg,
+        write_changes(self.ffmpeg,
                       self.ffplay,
                       self.ffprobe,
                       youtubedl,
