@@ -4,10 +4,10 @@ Name: configurator.py
 Porpose: Set Videomass configuration on startup
 Compatibility: Python3
 Author: Gianluca Pernigotto <jeanlucperni@gmail.com>
-Copyright: (c) 2018/2022 Gianluca Pernigotto <jeanlucperni@gmail.com>
+Copyleft - 2024 Gianluca Pernigotto <jeanlucperni@gmail.com>
 license: GPL3
-Rev: Feb.21.2022
-Code checker: pycodestyle, flake8, pylint .
+Rev: Apr.23.2024
+Code checker: flake8, pylint
 
  This file is part of Videomass.
 
@@ -33,36 +33,32 @@ from videomass.vdms_utils.utils import copydir_recursively
 from videomass.vdms_sys.settings_manager import ConfigManager
 
 
-def create_cache_dir(tmpdir):
+def msg(arg):
     """
-    This function is responsible for creating
-    the cache directory tree if not exists.
+    print logging messages during startup
+    """
+    print('Info:', arg)
+
+
+def create_dirs(dirname, fconf):
+    """
+    This function is responsible for the recursive creation
+    of directories required for Videomass if they do not exist.
     Returns dict:
         key == 'R'
         key == ERROR (if any errors)
     """
-    tmp = os.path.join(tmpdir, 'tmp')
-    if not os.path.exists(tmp):
-        try:  #
-            os.makedirs(tmp, mode=0o777)
-        except OSError as err:
-            return {'ERROR': err}
-    return {'R': None}
-
-
-def create_log_dir(logdir):
-    """
-    This function is responsible for creating
-    the log directory if not exists.
-    Returns dict:
-        key == 'R'
-        key == ERROR (if any errors)
-    """
-    if not os.path.exists(logdir):
+    if not os.path.exists(dirname):
         try:
-            os.makedirs(logdir, mode=0o777)
-        except OSError as err:
+            os.makedirs(dirname, mode=0o777)
+        except FileExistsError as err:
             return {'ERROR': err}
+        except OSError as err:
+            os.remove(fconf)  # force to restart on deleting
+            thismsg = ('Please try restarting Videomass to '
+                       'restore default settings now.')
+            return {'ERROR': f'{err}\n{thismsg}'}
+
     return {'R': None}
 
 
@@ -75,15 +71,14 @@ def restore_presets_dir(dirconf, srcpath):
     """
     if not os.path.exists(os.path.join(dirconf, "presets")):
         # try to restoring presets directory on videomass dir
-        drest = copydir_recursively(os.path.join(srcpath, "presets"),
-                                    dirconf)
+        drest = copydir_recursively(os.path.join(srcpath, "presets"), dirconf)
         if drest:
             return {'ERROR': drest}
 
     return {'R': None}
 
 
-def get_options(dirconf, fileconf):
+def get_options(dirconf, fileconf, srcpath, makeportable):
     """
     Check the application options. Reads the `settings.json`
     file; if it does not exist or is unreadable try to restore
@@ -96,10 +91,10 @@ def get_options(dirconf, fileconf):
         key == 'R'
         key == ERROR (if any errors)
     """
-    conf = ConfigManager(fileconf)
+    conf = ConfigManager(fileconf, makeportable)
     version = ConfigManager.VERSION
 
-    if os.path.exists(dirconf):  # if ~/.conf/videomass dir
+    if os.path.exists(dirconf):  # i.e ~/.conf/videomass dir
         if os.path.isfile(fileconf):
             data = {'R': conf.read_options()}
             if not data['R']:
@@ -115,10 +110,12 @@ def get_options(dirconf, fileconf):
             data = {'R': conf.read_options()}
 
     else:  # try to restore entire configuration directory
-        try:  # make conf folder
-            os.mkdir(dirconf, mode=0o777)
-        except (OSError, TypeError) as err:
-            data = {'ERROR': err}
+        dconf = copydir_recursively(srcpath,
+                                    os.path.dirname(dirconf),
+                                    "videomass",
+                                    )
+        if dconf:
+            data = {'ERROR': dconf}
         else:
             conf.write_options()
             data = {'R': conf.read_options()}
@@ -139,15 +136,15 @@ def get_pyinstaller():
     """
     if getattr(sys, 'frozen', False) and hasattr(sys, '_MEIPASS'):
         frozen, meipass = True, True
-        mpath = getattr(sys, '_MEIPASS', os.path.abspath(__file__))
-        data_locat = mpath
+        this = getattr(sys, '_MEIPASS', os.path.abspath(__file__))
+        data_locat = this
 
     else:
         frozen, meipass = False, False
-        mpath = os.path.realpath(os.path.abspath(__file__))
-        data_locat = os.path.dirname(os.path.dirname(mpath))
+        this = os.path.realpath(os.path.abspath(__file__))
+        data_locat = os.path.dirname(os.path.dirname(this))
 
-    return frozen, meipass, mpath, data_locat
+    return frozen, meipass, this, data_locat
 
 
 def conventional_paths():
@@ -163,6 +160,7 @@ def conventional_paths():
         dir_conf = os.path.join(user_name + "\\AppData\\Roaming\\videomass")
         log_dir = os.path.join(dir_conf, 'log')  # logs
         cache_dir = os.path.join(dir_conf, 'cache')  # updates executable
+        trash_dir = os.path.join(dir_conf, "Trash")
 
     elif platform.system() == "Darwin":
         fpath = "Library/Application Support/videomass/settings.json"
@@ -170,6 +168,7 @@ def conventional_paths():
         dir_conf = os.path.join(user_name, os.path.dirname(fpath))
         log_dir = os.path.join(user_name, "Library/Logs/videomass")
         cache_dir = os.path.join(user_name, "Library/Caches/videomass")
+        trash_dir = os.path.join(dir_conf, "Trash")
 
     else:  # Linux, FreeBsd, etc.
         fpath = ".config/videomass/settings.json"
@@ -177,50 +176,26 @@ def conventional_paths():
         dir_conf = os.path.join(user_name, ".config/videomass")
         log_dir = os.path.join(user_name, ".local/share/videomass/log")
         cache_dir = os.path.join(user_name, ".cache/videomass")
+        trash_dir = os.path.join(dir_conf, "Trash")
 
-    return file_conf, dir_conf, log_dir, cache_dir
+    return file_conf, dir_conf, log_dir, cache_dir, trash_dir
 
 
-def portable_paths(portdir):
+def portable_paths(portdirname):
     """
     Make portable-data paths based on OS
 
     """
-    if platform.system() == 'Windows':
-        file_conf = portdir + "\\portable_data\\settings.json"
-        dir_conf = portdir + "\\portable_data"
-        log_dir = os.path.join(dir_conf, 'log')  # logs
-        cache_dir = os.path.join(dir_conf, 'cache')  # updates executable
-    else:
-        file_conf = portdir + "/portable_data/settings.json"
-        dir_conf = portdir + "/portable_data"
-        log_dir = os.path.join(dir_conf, 'log')  # logs
-        cache_dir = os.path.join(dir_conf, 'cache')  # updates executable
+    dir_conf = portdirname
+    file_conf = os.path.join(dir_conf, "settings.json")
+    log_dir = os.path.join(dir_conf, 'log')  # logs
+    cache_dir = os.path.join(dir_conf, 'cache')  # updates executable
+    trash_dir = os.path.join(dir_conf, "Trash")
 
-    return file_conf, dir_conf, log_dir, cache_dir
+    if not os.path.exists(dir_conf):
+        os.makedirs(dir_conf, mode=0o777)
 
-
-def get_outdir(outdir, relpath):
-    """
-    On the application portable case, if relpath is True,
-    you need to make a folder named `My_Files` inside the
-    portable appdata.
-    """
-    if relpath is True:
-        appdir = os.getcwd()
-        outputdir = os.path.relpath(os.path.join(appdir, 'My_Files'))
-
-        if not os.path.exists(outputdir):
-            try:  # make a files folder
-                os.mkdir(outputdir, mode=0o777)
-            except OSError as err:
-                return None, err
-            except TypeError as err:
-                return None, err
-    else:
-        outputdir = outdir
-
-    return outputdir, None
+    return file_conf, dir_conf, log_dir, cache_dir, trash_dir
 
 
 def get_color_scheme(theme):
@@ -229,29 +204,25 @@ def get_color_scheme(theme):
     chosen theme in ("Videomass-Light",
                      "Videomass-Dark",
                      "Videomass-Colours",
-                     "Breeze",
-                     "Breeze-Dark",
-                     "Breeze-Blues"
+                     "Ubuntu-Light-Aubergine",
+                     "Ubuntu-Dark-Aubergine",
                      )
     """
-    if theme in ('Breeze-Blues', 'Videomass-Colours'):
-        c_scheme = {'BACKGRD': '#1c2027',  # DARK_SLATE background color
-                    'TXT0': '#FFFFFF',  # WHITE for title or URL in progress
-                    'TXT1': '#959595',  # GREY for all other text messages
-                    'ERR0': '#FF4A1B',  # ORANGE for error text messages
-                    'WARN': '#dfb72f',  # YELLOW for warning text messages
-                    'ERR1': '#EA312D',  # LIGHTRED for errors 2
-                    'SUCCESS': '#30ec30',  # Light GREEN when it is successful
-                    'TXT2': '#3f5e6b',  # dark ciano
-                    'TXT3': '#11b584',  # medium green
-                    'TXT4': '#87ceebff',  # light azure
-                    'TXT5': '#dd7ad0',  # LILLA
-                    'INFO': '#3298FB',  # AZURE
-                    'DEBUG': '#0ce3ac',  # light green
+    if theme == 'Videomass-Colours':
+        c_scheme = {'BACKGRD': '#8dc6c2',  # Ciano: background color
+                    'TXT0': '#d01d7a',  # Magenta: titles & end messages)
+                    'TXT1': '#ae11db',  # Purple for debug and others
+                    'ERR0': '#FF4A1B',  # ORANGE: errors 1 and others
+                    'WARN': '#7b6e01',  # YELLOW: warnings
+                    'ERR1': '#EA312D',  # LIGHTRED: errors 2
+                    'SUCCESS': '#017001',  # Light GREEN: successful
+                    'TXT3': '#333333',  # Dark grey: standard text
+                    'INFO': '#194c7e',  # Blue: other info messages
+                    'DEBUG': '#333333',  # light green
                     'FAILED': '#D21814',  # RED_DEEP if failed
-                    'ABORT': '#A41EA4',  # VIOLET the user stops the processes
+                    'ABORT': '#A41EA4',  # RED_DEEP if abort
                     }
-    elif theme in ('Breeze-Blues', 'Breeze-Dark', 'Videomass-Dark'):
+    elif theme == 'Videomass-Dark':
         c_scheme = {'BACKGRD': '#232424',  # DARK Grey background color
                     'TXT0': '#FFFFFF',  # WHITE for title or URL in progress
                     'TXT1': '#959595',  # GREY for all other text messages
@@ -259,43 +230,77 @@ def get_color_scheme(theme):
                     'WARN': '#dfb72f',  # YELLOW for warning text messages
                     'ERR1': '#EA312D',  # LIGHTRED for errors 2
                     'SUCCESS': '#30ec30',  # Light GREEN when it is successful
-                    'TXT2': '#008000',  # dark green
                     'TXT3': '#11b584',  # medium green
-                    'TXT4': '#87ceebff',  # light azure
-                    'TXT5': '#dd7ad0',  # LILLA
                     'INFO': '#118db5',  # AZURE
                     'DEBUG': '#0ce3ac',  # light green
                     'FAILED': '#D21814',  # RED_DEEP if failed
                     'ABORT': '#A41EA4',  # VIOLET the user stops the processes
                     }
-    elif theme in ('Breeze', 'Videomass-Light'):
+    elif theme == 'Videomass-Light':
         c_scheme = {'BACKGRD': '#ced0d1',  # WHITE background color
                     'TXT0': '#1f1f1f',  # BLACK for title or URL in progress
-                    'TXT1': '#778899ff',  # LIGHT_SLATE for all other text msg
+                    'TXT1': '#576470',  # LIGHT_SLATE for all other text msg
                     'ERR0': '#d25c07',  # ORANGE for error text messages
                     'WARN': '#988313',  # YELLOW for warning text messages
                     'ERR1': '#c8120b',  # LIGHTRED for errors 2
                     'SUCCESS': '#35a735',  # DARK_GREEN when it is successful
-                    'TXT2': '#008000',  # dark green
                     'TXT3': '#005c00',  # Light Green
-                    'TXT4': '#2651b8',  # blue
-                    'TXT5': '#dd7ad0',  # LILLA
                     'INFO': '#3298FB',  # AZURE
                     'DEBUG': '#005c00',  # Light Green
                     'FAILED': '#D21814',  # RED_DEEP if failed
                     'ABORT': '#A41EA4',  # VIOLET the user stops the processes
                     }
+    elif theme in ('Ubuntu-Dark-Aubergine', 'Ubuntu-Light-Aubergine'):
+        c_scheme = {'BACKGRD': '#2C001E',  # Dark-Aubergine background color
+                    'TXT0': '#FFFFFF',  # WHITE for titles
+                    'TXT1': '#8AB8E6',  # light Blue
+                    'ERR0': '#E95420',  # ORANGE for error text messages
+                    'WARN': '#dfb72f',  # YELLOW for warning messages
+                    'ERR1': '#F90808',  # RED_DEEP
+                    'SUCCESS': '#ABD533',  # Light GREEN when it is successful
+                    'TXT3': '#AEA79F',  # Ubuntu warm grey (base foreground)
+                    'INFO': '#F7C3B1',  # Ubuntu orange light 30%
+                    'DEBUG': '#8AB8E6',  # light Blue
+                    'FAILED': '#F90808',  # RED_DEEP
+                    'ABORT': '#F90808',  # RED_DEEP
+                    }
     else:
         c_scheme = {'ERROR': f'Unknow theme "{theme}"'}
 
     return c_scheme
 
 
-def msg(arg):
+def data_location(args):
     """
-    print logging messages during startup
+    Determines data location and modes to make the app
+    portable, fully portable or using conventional paths.
+    return data location.
     """
-    print('Info:', arg)
+    frozen, meipass, this, locat = get_pyinstaller()
+    workdir = os.path.dirname(os.path.dirname(os.path.dirname(this)))
+
+    if args['make_portable']:
+        portdir = args['make_portable']
+        (conffile, confdir, logdir,
+         cachedir, trash_dir) = portable_paths(portdir)
+    else:
+        conffile, confdir, logdir, cachedir, trash_dir = conventional_paths()
+
+    return {"conffile": conffile,
+            "confdir": confdir,
+            "logdir": logdir,
+            "cachedir": cachedir,
+            "trashdir_default": trash_dir,
+            "this": this,
+            "frozen": frozen,
+            "meipass": meipass,
+            "locat": locat,
+            "localepath": os.path.join(locat, 'locale'),
+            "workdir": workdir,
+            "srcpath": os.path.join(locat, 'share'),
+            "icodir": os.path.join(locat, 'art', 'icons'),
+            "ffmpeg_pkg": os.path.join(locat, 'FFMPEG'),
+            }
 
 
 class DataSource():
@@ -310,60 +315,36 @@ class DataSource():
         - Bundled app by pyinstaller (windowed for MacOs and Windows)
         - AppImage for Linux (user)
 
-        * multiuser: root installation
+        * multiuser: system installation
         * user: local installation
 
     """
-    FROZEN, MEIPASS, MPATH, DATA_LOCAT = get_pyinstaller()
-    portdirname = os.path.dirname(sys.executable)
-    portdir = os.path.join(portdirname, 'portable_data')
-
-    if FROZEN and MEIPASS and os.path.isdir(portdir):
-        # if portdir is true, make application really portable
-        FILE_CONF, DIR_CONF, LOG_DIR, CACHE_DIR = portable_paths(portdirname)
-        RELPATH = platform.system() == 'Windows'
-
-    elif os.path.isdir(os.path.join(DATA_LOCAT, 'portable_data')):
-        # Remember to add portable_data/ folder within videomass/
-        FILE_CONF, DIR_CONF, LOG_DIR, CACHE_DIR = portable_paths(DATA_LOCAT)
-        RELPATH = False  # to debug relative paths, set to True
-
-    else:
-        FILE_CONF, DIR_CONF, LOG_DIR, CACHE_DIR = conventional_paths()
-        RELPATH = False
     # -------------------------------------------------------------------
 
-    def __init__(self):
+    def __init__(self, kwargs):
         """
-        Given the pathnames defined by `DATA_LOCAT` it performs
-        the initialization described in DataSource.
-
-            `self.srcpath` > configuration folder for recovery
-            `self.icodir` > set of icons
-            `self.localepath` > locale folder
+        Having the pathnames returned by `dataloc` it
+        performs the initialization described in DataSource.
 
         """
+        self.dataloc = data_location(kwargs)
+        self.relativepaths = bool(kwargs['make_portable'])
+        self.makeportable = kwargs['make_portable']
         self.apptype = None  # appimage, pyinstaller on None
-        self.workdir = os.path.dirname(os.path.dirname
-                                       (os.path.dirname(DataSource.MPATH))
-                                       )
-        self.localepath = os.path.join(DataSource.DATA_LOCAT, 'locale')
-        self.srcpath = os.path.join(DataSource.DATA_LOCAT, 'share')
-        self.icodir = os.path.join(DataSource.DATA_LOCAT, 'art', 'icons')
-        self.ffmpeg_pkg = os.path.join(DataSource.DATA_LOCAT, 'FFMPEG')
-        launcher = os.path.isfile(f'{self.workdir}/launcher')
+        launcher = os.path.isfile(f"{self.dataloc['workdir']}/launcher")
 
-        if DataSource.FROZEN and DataSource.MEIPASS or launcher:
-            msg(f'frozen={DataSource.FROZEN} '
-                f'meipass={DataSource.MEIPASS} '
-                f'launcher={launcher}')
+        if self.dataloc['frozen'] and self.dataloc['meipass'] or launcher:
+            msg(f"frozen={self.dataloc['frozen']} "
+                f"meipass={self.dataloc['meipass']} "
+                f"launcher={launcher}")
 
             self.apptype = 'pyinstaller' if not launcher else None
-            self.prg_icon = f"{self.icodir}/videomass.png"
+            self.prg_icon = f"{self.dataloc['icodir']}/videomass.png"
 
         elif ('/tmp/.mount_' in sys.executable or os.path.exists(
               os.path.dirname(os.path.dirname(os.path.dirname(
-                  sys.argv[0]))) + '/AppRun')):
+                  sys.argv[0])))
+              + '/AppRun')):
             # embedded on python appimage
             msg('Embedded on python appimage')
             self.apptype = 'appimage'
@@ -380,7 +361,7 @@ class DataSource():
                 # dirname = os.path.dirname(sys.executable)
                 # pythonpath = os.path.join(dirname, 'Script', 'videomass')
                 # self.icodir = dirname + '\\share\\videomass\\icons'
-                self.prg_icon = self.icodir + "\\videomass.png"
+                self.prg_icon = self.dataloc['icodir'] + "\\videomass.png"
 
             elif binarypath == '/usr/local/bin/videomass':
                 msg(f'executable={binarypath}')
@@ -396,7 +377,7 @@ class DataSource():
 
             else:
                 msg(f'executable={binarypath}')
-                # pip as normal user, usually Linux, MacOs, Unix
+                # pip as user, usually Linux, MacOs, Unix
                 if binarypath is None:
                     # need if user $PATH is not set yet
                     userbase = site.getuserbase()
@@ -415,39 +396,43 @@ class DataSource():
         fatal error in the gui_app bootstrap.
         """
         # handle configuration file
-        userconf = get_options(DataSource.DIR_CONF, DataSource.FILE_CONF)
+        userconf = get_options(self.dataloc['confdir'],
+                               self.dataloc['conffile'],
+                               self.dataloc['srcpath'],
+                               self.makeportable,
+                               )
         if userconf.get('ERROR'):
             return userconf
         userconf = userconf['R']
+
         # restore presets folder
-        presets_rest = restore_presets_dir(DataSource.DIR_CONF, self.srcpath)
+        presets_rest = restore_presets_dir(self.dataloc['confdir'],
+                                           self.dataloc['srcpath'],
+                                           )
         if presets_rest.get('ERROR'):
             return presets_rest
-        # create cache dir
-        cachedir = create_cache_dir(DataSource.CACHE_DIR)
-        if cachedir.get('ERROR'):
-            return cachedir
-        # create log dir
-        logdir = create_log_dir(DataSource.LOG_DIR)
-        if logdir.get('ERROR'):
-            return logdir
+
+        # create the required directories if not existing
+        requiredirs = (os.path.join(self.dataloc['cachedir'], 'tmp'),
+                       self.dataloc['logdir'],
+                       userconf['outputdir'],
+                       userconf['ydlp-outputdir'],
+                       self.dataloc['trashdir_default']
+                       )
+        if not userconf['trashdir_loc'].strip():
+            userconf['trashdir_loc'] = self.dataloc['trashdir_default']
+        for dirs in requiredirs:
+            create = create_dirs(dirs, self.dataloc['conffile'],)
+            if create.get('ERROR'):
+                return create
+
         # set color scheme
         theme = get_color_scheme(userconf['icontheme'])
-        userconf['icontheme'] = (userconf['icontheme'], theme)
+        userconf['colorscheme'] = theme
         if theme.get('ERROR'):
             return theme
 
-        # set output directories
-        outfile = get_outdir(userconf['outputfile'], DataSource.RELPATH)
-        userconf['outputfile'] = outfile[0]
-        outdownl = get_outdir(userconf['outputdownload'], DataSource.RELPATH)
-        userconf['outputdownload'] = outfile[0]
-        if outfile[1]:
-            return {'ERROR': f'{outfile[1]}'}
-        if outdownl[1]:
-            return {'ERROR': f'{outdownl[1]}'}
-
-        def _relativize(path, relative=DataSource.RELPATH):
+        def _relativize(path, relative=self.relativepaths):
             """
             Returns a relative pathname if *relative* param is True.
             If not, it returns the given pathname. Also return the given
@@ -456,27 +441,31 @@ class DataSource():
             """
             try:
                 return os.path.relpath(path) if relative else path
-            except ValueError:
+            except (ValueError, TypeError):
                 # return {'ERROR': f'{error}'}  # use `as error` here
                 return path
 
         return ({'ostype': platform.system(),
-                 'srcpath': _relativize(self.srcpath),
-                 'localepath': _relativize(self.localepath),
-                 'fileconfpath': _relativize(DataSource.FILE_CONF),
-                 'workdir': _relativize(self.workdir),
-                 'confdir': _relativize(DataSource.DIR_CONF),
-                 'logdir': _relativize(DataSource.LOG_DIR),
-                 'cachedir': _relativize(DataSource.CACHE_DIR),
-                 'FFMPEG_videomass_pkg': _relativize(self.ffmpeg_pkg),
+                 'srcpath': _relativize(self.dataloc['srcpath']),
+                 'localepath': _relativize(self.dataloc['localepath']),
+                 'fileconfpath': _relativize(self.dataloc['conffile']),
+                 'workdir': _relativize(self.dataloc['workdir']),
+                 'confdir': _relativize(self.dataloc['confdir']),
+                 'logdir': _relativize(self.dataloc['logdir']),
+                 'cachedir': _relativize(self.dataloc['cachedir']),
+                 'trashdir_default':
+                     _relativize(self.dataloc['trashdir_default']),
+                 'FFMPEG_videomass_pkg':
+                     _relativize(self.dataloc['ffmpeg_pkg']),
                  'app': self.apptype,
-                 'relpath': DataSource.RELPATH,
+                 'relpath': self.relativepaths,
                  'getpath': _relativize,
                  'ffmpeg_cmd': _relativize(userconf['ffmpeg_cmd']),
                  'ffprobe_cmd': _relativize(userconf['ffprobe_cmd']),
                  'ffplay_cmd': _relativize(userconf['ffplay_cmd']),
-                 "ffplay+params": "-hide_banner",
-                 "ffmpeg+params": "-stats -hide_banner -nostdin",
+                 'ffmpeg-default-args': '-y -stats -hide_banner',
+                 'ffplay-default-args': '-hide_banner',
+                 'yt_dlp': '',
                  **userconf
                  })
     # --------------------------------------------------------------------
@@ -491,42 +480,44 @@ class DataSource():
         """
         keys = ('videomass', 'A/V-Conv', 'startconv', 'fileproperties',
                 'playback', 'concatenate', 'preview', 'clear',
-                'profile_append', 'scale', 'crop', 'rotate', 'deinterlace',
-                'denoiser', 'statistics', 'settings', 'audiovolume',
-                'youtube', 'presets_manager', 'profile_add', 'profile_del',
-                'profile_edit', 'previous', 'next', 'startdownload',
-                'download_properties', 'stabilizer', 'listindx')
-
-        ext = 'svg' if 'wx.svg' in sys.modules else 'png'
+                'addtoprst', 'scale', 'crop', 'rotate', 'deinterlace',
+                'denoiser', 'volanalyze', 'settings', 'audiovolume',
+                'presets_manager', 'profile_add', 'profile_del',
+                'profile_edit', 'previous', 'next', 'stabilizer',
+                'preview_audio', 'profile_copy', 'slideshow',
+                'videotopictures', 'atrack', 'timerset', 'coloreq',
+                'stop', 'home', 'youtube', 'playlist',
+                'download', 'statistics', 'play', 'subtitles',
+                'proc-queue', 'add-queue', 'options', 'delpreset',
+                'exportall', 'exportselected', 'importfolder', 'importpreset',
+                'newpreset', 'reload', 'restoreall', 'restoreselected',
+                )  # must match with items on `iconset` tuple, see following
 
+        icodir = self.dataloc['icodir']
         iconames = {'Videomass-Light':  # Videomass icons for light themes
-                    {'x48': f'{self.icodir}/Sign_Icons/48x48_light',
-                     'x16': f'{self.icodir}/Videomass-Light/16x16',
-                     'x22': f'{self.icodir}/Videomass-Light/24x24'},
+                    {'x48': f'{icodir}/Sign_Icons/48x48_light',
+                     'x16': f'{icodir}/Videomass-Light/16x16',
+                     'x22': f'{icodir}/Videomass-Light/24x24'},
                     'Videomass-Dark':  # Videomass icons for dark themes
-                    {'x48': f'{self.icodir}/Sign_Icons/48x48_dark',
-                     'x16': f'{self.icodir}/Videomass-Dark/16x16',
-                     'x22': f'{self.icodir}/Videomass-Dark/24x24'},
+                    {'x48': f'{icodir}/Sign_Icons/48x48_dark',
+                     'x16': f'{icodir}/Videomass-Dark/16x16',
+                     'x22': f'{icodir}/Videomass-Dark/24x24'},
                     'Videomass-Colours':  # Videomass icons for all themes
-                    {'x48': f'{self.icodir}/Sign_Icons/48x48',
-                     'x16': f'{self.icodir}/Videomass-Colours/16x16',
-                     'x22': f'{self.icodir}/Videomass-Colours/24x24'},
-                    'Breeze':  # Breeze for light themes
-                    {'x48': f'{self.icodir}/Sign_Icons/48x48_light',
-                     'x16': f'{self.icodir}/Breeze/16x16',
-                     'x22': f'{self.icodir}/Breeze/22x22'},
-                    'Breeze-Dark':  # breeze for dark themes
-                    {'x48': f'{self.icodir}/Sign_Icons/48x48_dark',
-                     'x16': f'{self.icodir}/Breeze-Dark/16x16',
-                     'x22': f'{self.icodir}/Breeze-Dark/22x22'},
-                    'Breeze-Blues':  # breeze custom colorized for all themes
-                    {'x48': f'{self.icodir}/Sign_Icons/48x48',
-                     'x16': f'{self.icodir}/Breeze-Blues/16x16',
-                     'x22': f'{self.icodir}/Breeze-Blues/22x22'}
+                    {'x48': f'{icodir}/Sign_Icons/48x48',
+                     'x16': f'{icodir}/Videomass-Colours/16x16',
+                     'x22': f'{icodir}/Videomass-Colours/24x24'},
+                    'Ubuntu-Dark-Aubergine':  # Videomass icons for all themes
+                    {'x48': f'{icodir}/Sign_Icons/48x48_dark',
+                     'x16': f'{icodir}/Videomass-Dark/16x16',
+                     'x22': f'{icodir}/Videomass-Dark/24x24'},
+                    'Ubuntu-Light-Aubergine':  # Videomass icons for all themes
+                    {'x48': f'{icodir}/Sign_Icons/48x48_light',
+                     'x16': f'{icodir}/Videomass-Light/16x16',
+                     'x22': f'{icodir}/Videomass-Light/24x24'},
                     }
 
         choose = iconames.get(icontheme)  # set appropriate icontheme
-
+        ext = 'svg' if 'wx.svg' in sys.modules else 'png'
         iconset = (self.prg_icon,
                    f"{choose.get('x48')}/icon_videoconversions.{ext}",
                    f"{choose.get('x22')}/convert.{ext}",
@@ -535,27 +526,50 @@ class DataSource():
                    f"{choose.get('x48')}/icon_concat.{ext}",
                    f"{choose.get('x16')}/preview.{ext}",
                    f"{choose.get('x16')}/edit-clear.{ext}",
-                   f"{choose.get('x22')}/profile-append.{ext}",
+                   f"{choose.get('x16')}/addtoprst.{ext}",
                    f"{choose.get('x16')}/transform-scale.{ext}",
                    f"{choose.get('x16')}/transform-crop.{ext}",
                    f"{choose.get('x16')}/transform-rotate.{ext}",
                    f"{choose.get('x16')}/deinterlace.{ext}",
                    f"{choose.get('x16')}/denoise.{ext}",
-                   f"{choose.get('x16')}/statistics.{ext}",
+                   f"{choose.get('x16')}/volanalyze.{ext}",
                    f"{choose.get('x16')}/configure.{ext}",
                    f"{choose.get('x16')}/player-volume.{ext}",
-                   f"{choose.get('x48')}/icon_youtube.{ext}",
                    f"{choose.get('x48')}/icon_prst_mng.{ext}",
                    f"{choose.get('x16')}/newprf.{ext}",
                    f"{choose.get('x16')}/delprf.{ext}",
                    f"{choose.get('x16')}/editprf.{ext}",
                    f"{choose.get('x22')}/go-previous.{ext}",
                    f"{choose.get('x22')}/go-next.{ext}",
+                   f"{choose.get('x16')}/stabilizer.{ext}",
+                   f"{choose.get('x16')}/preview_audio.{ext}",
+                   f"{choose.get('x16')}/copyprf.{ext}",
+                   f"{choose.get('x48')}/icon_slideshow.{ext}",
+                   f"{choose.get('x48')}/icon_videopictures.{ext}",
+                   f"{choose.get('x16')}/audiotrack.{ext}",
+                   f"{choose.get('x16')}/timer.{ext}",
+                   f"{choose.get('x16')}/coloreq.{ext}",
+                   f"{choose.get('x22')}/stop.{ext}",
+                   f"{choose.get('x22')}/home.{ext}",
+                   f"{choose.get('x48')}/youtube.{ext}",
+                   f"{choose.get('x16')}/playlist.{ext}",
                    f"{choose.get('x22')}/download.{ext}",
                    f"{choose.get('x22')}/statistics.{ext}",
-                   f"{choose.get('x16')}/stabilizer.{ext}",
-                   f"{choose.get('x16')}/playlist-append.{ext}",
+                   f"{choose.get('x22')}/play.{ext}",
+                   f"{choose.get('x16')}/subtitles.{ext}",
+                   f"{choose.get('x22')}/proc-queue.{ext}",
+                   f"{choose.get('x22')}/add-queue.{ext}",
+                   f"{choose.get('x22')}/options.{ext}",
+                   f"{choose.get('x16')}/delpreset.{ext}",
+                   f"{choose.get('x16')}/exportall.{ext}",
+                   f"{choose.get('x16')}/exportselected.{ext}",
+                   f"{choose.get('x16')}/importfolder.{ext}",
+                   f"{choose.get('x16')}/importpreset.{ext}",
+                   f"{choose.get('x16')}/newpreset.{ext}",
+                   f"{choose.get('x16')}/reload.{ext}",
+                   f"{choose.get('x16')}/restoreall.{ext}",
+                   f"{choose.get('x16')}/restoreselected.{ext}",
                    )
-        values = [os.path.join(norm) for norm in iconset]  # normalize pathns
+        values = (os.path.join(norm) for norm in iconset)  # normalize pathns
 
         return dict(zip(keys, values))
